<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="html" />

<xsl:template match="/">
	<xsl:apply-templates select="//attributes" />
</xsl:template>

<xsl:template match="attributes">
	<html><head>
	<link rel="stylesheet" href="../css/modelscope.css" type="text/css" />
	<script language="JavaScript" src="../scripts/checkFields.js"></script>
	<script language="JavaScript" src="../scripts/rules.js"></script>
	<script language="JavaScript">
	function checkForm(f) {
		var fieldName;
		var datatype;
		var value;
		<xsl:apply-templates select="//value_attribute[@visibility='visible']" mode="validate" />
		return true;
	}	
	</script>	
	</head><body>
	<form name="event" method="GET" onsubmit="return checkForm(this);">
	<input type="hidden" name="fnc" value="7" />
	<!-- set the form hidden fields for subset, behaviour, instance id and event name -->
	<input type="hidden" name="sub">
	<xsl:attribute name="value"><xsl:value-of select="//subset/name" /></xsl:attribute>
	</input>
	<input type="hidden" name="beh">
	<xsl:attribute name="value"><xsl:value-of select="//behaviour/name" /></xsl:attribute>
	</input>
	<input type="hidden" name="obj">
	<xsl:attribute name="value"><xsl:value-of select="//instance/id" /></xsl:attribute>
	</input>
	<input type="hidden" name="evt">
	<xsl:attribute name="value"><xsl:value-of select="//event/name" /></xsl:attribute>
	</input>
	<center><table border="0">
	
	<!-- hidden attributes -->
	
	<xsl:apply-templates select="//value_attribute[@visibility='hidden']" mode="input" />
	
	<!-- visible attributes -->

	<xsl:apply-templates select="//attribute" mode="input"/>

	<!-- add a submit button for this event -->
	<tr><td colspan="2" align="center">
	<input type="submit">
	<xsl:attribute name="value"><xsl:value-of select="//event/name" /></xsl:attribute>
	<!-- disable the event if any reference lists are empty -->
	<xsl:if test="count(//reference_type_list[@size = 0])">
		<xsl:attribute name="disabled">disabled</xsl:attribute>
	</xsl:if>
	</input>
	</td></tr>
	<xsl:if test="@visibleAttributeCount != 0">
	<tr><td colspan="2" align="center">
	<input type="reset" value="reset form">
	</input>
	</td></tr>
	</xsl:if>
	</table></center>
	</form>
	</body></html>
</xsl:template>

<xsl:template match="value_attribute[@visibility='visible']" mode="validate">
	fieldName = "$<xsl:value-of select="name"/>";
	datatype = "<xsl:value-of select="datatype"/>";
	value = document.forms.event.elements[fieldName].value;
	if (!checkValueType(value, datatype)) {
		alert("'" + fieldName.substring(1) + "' does not contain a valid " + datatype);
		return false;
		}
	<xsl:if test="@hasRule='yes'">
	if (typeof(<xsl:value-of select="rule" />) == "undefined") {
		alert("Failure to execute validation rule '<xsl:value-of select="rule" />'");
		return false;
		}
	if (!eval(<xsl:value-of select="rule" />)) {
		alert("<xsl:value-of select="message" />");
		return false;
		}
	</xsl:if>
</xsl:template>

<xsl:template match="value_attribute[@visibility='hidden']" mode="input">
	<input type="hidden">
	<xsl:attribute name="name">$<xsl:value-of select="name" /></xsl:attribute>
	<xsl:attribute name="value"><xsl:value-of select="value_type/value" /></xsl:attribute>
	</input>
</xsl:template>

<xsl:template match="attribute" mode="input">
	<xsl:apply-templates mode="input"/>
</xsl:template>

<xsl:template match="value_attribute[@visibility='visible']" mode="input">
	<tr>
	<td align="right" valign="middle" class="attributeName">
	<xsl:value-of select="name" /> <!-- : <xsl:value-of select="datatype" /> -->
	</td>
	<td align="left" valign="middle">
	<xsl:choose>
	<xsl:when test="datatype='Boolean'">
	<span class="attributeValue">True</span>
	<input type="radio" value="true">
	<xsl:attribute name="name">$<xsl:value-of select="name" /></xsl:attribute>
	<xsl:if test="value_type/value='true'"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
	</input>
	<span class="attributeValue">False</span>
	<input type="radio" value="false">
	<xsl:attribute name="name">$<xsl:value-of select="name" /></xsl:attribute>	
	<xsl:if test="value_type/value='false'"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
	</input>	
	</xsl:when>
	<xsl:otherwise>
	<input type="text" size="20">
	<xsl:attribute name="name">$<xsl:value-of select="name" /></xsl:attribute>
	<xsl:attribute name="value"><xsl:value-of select="value_type/value" /></xsl:attribute>
	</input>
	</xsl:otherwise>
	</xsl:choose>
	</td>
	<td align="left" valign="middle" class="attributeValue"><xsl:value-of select="datatype" /></td>
	</tr>
</xsl:template>

<xsl:template match="reference_list_attribute" mode="input">
	<tr>
	<td align="right" valign="top" class="attributeName">
	<xsl:value-of select="name" /> <!-- : <xsl:value-of select="datatype" /> -->
	</td>
	<td align="left" valign="top">
	<xsl:choose>
	<xsl:when test="reference_type_list/@size = 0">
		<select size="1" disabled="disabled">
		<option>None in context</option>
		</select>
	</xsl:when>
	<xsl:otherwise>
		<select size="1">
		<xsl:attribute name="name">$<xsl:value-of select="name" /></xsl:attribute>
		<xsl:apply-templates select="reference_type_list/reference_type" mode="list">
			<xsl:sort select="./name" />
			<xsl:sort select="./id" />
		</xsl:apply-templates>
		</select>
	</xsl:otherwise>
	</xsl:choose>
	</td>
	<td align="left" valign="middle" class="attributeValue"><xsl:value-of select="datatype" /></td>
	</tr>
</xsl:template>

<xsl:template match="reference_type" mode="list">
	<option>
	<xsl:attribute name="value"><xsl:value-of select="id" /></xsl:attribute>
	<xsl:choose>
		<xsl:when test="./@isAllowed = 'true' and ./@isDesired='false'">
			<xsl:attribute name="class">allowedButNotDesired</xsl:attribute>	
		</xsl:when>
		<xsl:when test="./@isAllowed = 'false' and ./@isDesired='false'">
			<xsl:attribute name="class">notAllowed</xsl:attribute>	
		</xsl:when>
		<xsl:when test="./@isAllowed = 'true' and ./@isDesired='true'">
			<xsl:attribute name="class">desired</xsl:attribute>	
		</xsl:when>
		<xsl:when test="./@isAllowed = 'false' and ./@isDesired='true'">
			<xsl:attribute name="class">desiredButNotAllowed</xsl:attribute>	
		</xsl:when>
	</xsl:choose>
	<xsl:if test="id = ../../@tag">
		<xsl:attribute name="selected">true</xsl:attribute>
	</xsl:if>
	<xsl:choose>
	<xsl:when test="id &lt; 0">(new <xsl:value-of select="name" />)</xsl:when>
	<xsl:otherwise><xsl:value-of select="name" /></xsl:otherwise>
	</xsl:choose>
	</option>
</xsl:template>

<xsl:template match="reference_attribute" mode="input">
	<input type="hidden">
	<xsl:attribute name="name">$<xsl:value-of select="name" /></xsl:attribute>
	<xsl:attribute name="value"><xsl:value-of select="reference_type/id" /></xsl:attribute>
	</input>
</xsl:template>

<xsl:template match="reference_attribute_name">
	referenceAttributes[<xsl:value-of select="id" />] = "$<xsl:value-of select="name" />";
</xsl:template>

</xsl:stylesheet>	
